@@ -514,7 +514,7 @@ define([
 
         renderDataPage(renderedText, isHtml = true) {
             var tag = new com_String();
-            tag.appendFormatLine('<div class="{0} vp-close-on-blur vp-scrollbar">', 'rendered_html'); // 'rendered_html' style from jupyter output area
+            tag.appendFormatLine('<div class="{0} vp-close-on-blur vp-scrollbar">', 'vp_rendered_html'); // 'rendered_html' style from jupyter output area
             if (isHtml) {
                 tag.appendLine(renderedText);
             } else {
@@ -543,20 +543,20 @@ define([
                     }
                 } else {
                     var errorContent = '';
-                    if (msg.content.ename) {
-                        errorContent = com_util.templateForErrorBox(msg.content.ename, msg.content.evalue);
+                    if (msg.content && msg.content.ename) {
+                        errorContent = com_util.templateForErrorBox(msg.content.ename, msg.content?.evalue);
                     }
+                    vpLog.display(VP_LOG_TYPE.ERROR, msg.content?.ename, msg.content?.evalue, msg.content);
                     that.renderDataPage(errorContent);
-                    vpLog.display(VP_LOG_TYPE.ERROR, msg.content.ename, msg.content.evalue, msg.content);
                 }
             }).catch(function(resultObj) {
                 let { msg } = resultObj;
                 var errorContent = '';
-                if (msg.content.ename) {
-                    errorContent = com_util.templateForErrorBox(msg.content.ename, msg.content.evalue);
+                if (msg.content && msg.content.ename) {
+                    errorContent = com_util.templateForErrorBox(msg.content.ename, msg.content?.evalue);
                 }
+                vpLog.display(VP_LOG_TYPE.ERROR, msg.content?.ename, msg.content?.evalue, msg.content);
                 that.renderDataPage(errorContent);
-                vpLog.display(VP_LOG_TYPE.ERROR, msg.content.ename, msg.content.evalue, msg.content);
             });
         }
 
@@ -643,7 +643,7 @@ define([
             page.appendFormatLine('<div class="{0}">', 'vp-gb-method-user');
             page.appendFormatLine('<label class="vp-bold">{0}</label>', 'User option');
             page.appendFormatLine('<input type="text" placeholder="{0}" id="vp_gbMethodUser"/>', 'Type user method');
-            page.appendFormatLine('<label><input id="vp_gbMethodUserAsText" type="checkbox" checked/><span>{0}</span></label>'
+            page.appendFormatLine('<label><input id="vp_gbMethodUserAsText" type="checkbox"/><span>{0}</span></label>'
                                 , 'Text');
             page.appendLine('<button id="vp_gbMethodUserAdd" class="vp-button">Add</button>');
             page.appendLine('</div>');
@@ -886,7 +886,12 @@ define([
                 // Method code generation
                 //================================================================
                 if (method != '') {
-                    methodStr.appendFormat('{0}()', method);
+                    let numericOnlyList = ['std', 'sum', 'mean', 'median', 'quantile'];
+                    if (numericOnlyList.includes(method)) {
+                        methodStr.appendFormat('{0}(numeric_only=True)', method);
+                    } else {
+                        methodStr.appendFormat('{0}()', method);
+                    }
                 }
             }
 
